package com.esignlive.guidance.forum;

import java.text.ParseException;
import java.util.Arrays;

import com.silanis.esl.sdk.ConditionalField;
import com.silanis.esl.sdk.Document;
import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.ExtractionType;
import com.silanis.esl.sdk.Field;
import com.silanis.esl.sdk.FieldCondition;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.PackageStatus;
import com.silanis.esl.sdk.Signature;
import com.silanis.esl.sdk.builder.DocumentBuilder;
import com.silanis.esl.sdk.builder.FieldConditionBuilder;
import com.silanis.esl.sdk.builder.PackageBuilder;
import com.silanis.esl.sdk.builder.SignerBuilder;

public class _21_07_22_text_tags_plus_conditional_fields {
	public static final String API_KEY = "your_api_key";
	public static final String API_URL = "https://sandbox.esignlive.com/api";
	public static final String FILE_PATH = "your_file_path\\text tags example with conditional fields.docx";



	public static void main(String[] args) throws ParseException {

		EslClient eslClient = new EslClient(API_KEY, API_URL);
	
		//step1: create a package with text tags
		DocumentPackage pkg = PackageBuilder.newPackageNamed("Text Tag Example Package")
                .withStatus(PackageStatus.DRAFT)
                .withSigner(SignerBuilder.newSignerWithEmail("signer1@mailinator.com")
                        .withFirstName("John")
                        .withLastName("Smith")
                        .withCustomId("Signer1")
                        )
                .withDocument(DocumentBuilder.newDocumentWithName("Sample Contract")
                		.withId("newDocument")
                        .fromFile(FILE_PATH)
                        .withExtractionType(ExtractionType.TEXT_TAGS)
                        .enableExtraction())
                .build();
			
		
		PackageId createPackageOneStep = eslClient.createPackageOneStep(pkg);
		
		
		//step2: add condition to the field
		DocumentPackage createdPkg = eslClient.getPackage(createPackageOneStep);
		for (Document document : createdPkg.getDocuments()) {
			for (Signature signature : document.getSignatures()) {
				for (Field field : signature.getFields()) {
					if(field.getId().getId().equals("checkbox1")) {
						
						FieldCondition newRadioButtoncondition1 = FieldConditionBuilder.newFieldCondition()
								.withId("newConditionId1")
								.withCondition("document['newDocument'].field['checkbox1'].value == 'X'")
								.withAction("document['newDocument'].field['textfield1'].required = true")
								.build();
						
						ConditionalField copyFieldToConditionalField = copyFieldToConditionalField(field);
						copyFieldToConditionalField.setConditions(Arrays.asList(newRadioButtoncondition1));
						eslClient.getApprovalService().updateConditionalField(createPackageOneStep, document.getId().getId(), signature.getId(), copyFieldToConditionalField);
						break;	
					}
				}
			}
		}
		
		//step3: send package
		eslClient.sendPackage(createPackageOneStep);
		

	}
	
	private static ConditionalField copyFieldToConditionalField(Field field) {
		ConditionalField conditionalField = new ConditionalField();
		conditionalField.setExtraction(field.isExtraction()); 
		conditionalField.setFieldValidator(field.getFieldValidator());
		conditionalField.setFontSize(field.getFontSize());
		conditionalField.setHeight(field.getHeight());
		conditionalField.setId(field.getId());
		conditionalField.setName(field.getName());
		conditionalField.setPage(field.getPage());
		conditionalField.setStyle(field.getStyle());
//		conditionalField.setTextAnchor(field.getTextAnchor());		//text anchor is only useful when upload the document
		conditionalField.setValue(field.getValue());
		conditionalField.setWidth(field.getWidth());
		conditionalField.setX(field.getX());
		conditionalField.setY(field.getY());
		return conditionalField;
	}

}
